package com.cyl.manager.ums.service;

import com.cyl.manager.ums.domain.PetCare;

import java.util.List;

/**
 * 宠物服务档案Service接口
 * 
 * @author daixiande
 */
public interface PetCareService {
    /**
     * 查询宠物服务档案
     * 
     * @param id 宠物服务档案主键
     * @return 宠物服务档案
     */
    PetCare selectPetCareById(Integer id);

    /**
     * 查询宠物服务档案列表
     * 
     * @param petCare 宠物服务档案
     * @return 宠物服务档案集合
     */
    List<PetCare> selectPetCareList(PetCare petCare);

    /**
     * 新增宠物服务档案
     * 
     * @param petCare 宠物服务档案
     * @return 结果
     */
    int insertPetCare(PetCare petCare);

    /**
     * 修改宠物服务档案
     * 
     * @param petCare 宠物服务档案
     * @return 结果
     */
    int updatePetCare(PetCare petCare);

    /**
     * 批量删除宠物服务档案
     * 
     * @param ids 需要删除的宠物服务档案主键集合
     * @return 结果
     */
    int deletePetCareByIds(Integer[] ids);

    /**
     * 删除宠物服务档案信息
     * 
     * @param id 宠物服务档案主键
     * @return 结果
     */
    int deletePetCareById(Integer id);
}
